@@ -1,14 +1,13 @@
 package Text::Table::Tiny;
-$Text::Table::Tiny::VERSION = '1.01_01'; # TRIAL
-
-$Text::Table::Tiny::VERSION = '1.0101';use 5.010;
+$Text::Table::Tiny::VERSION = '1.01';
+use 5.010;
 use strict;
 use warnings;
 use utf8;
 use parent 'Exporter';
-use Carp                    qw/ croak /;
-use Ref::Util         0.202 qw/ is_arrayref /;
-use String::TtyLength 0.02  qw/ tty_width /;
+use Carp                qw/ croak /;
+use Ref::Util           qw/ is_arrayref is_ref /;
+use String::TtyLength   qw/ tty_length /;
 
 our @EXPORT_OK = qw/ generate_table /;
 
@@ -166,17 +165,17 @@ sub _format_column
     my $pad = $param->{compact} ? '' : ' ';
 
     if ($align eq 'r' || $align eq 'right') {
-        return $pad.' ' x ($width - tty_width($text)).$text.$pad;
+        return $pad.' ' x ($width - tty_length($text)).$text.$pad;
     }
     elsif ($align eq 'c' || $align eq 'center' || $align eq 'centre') {
-        my $total_spaces = $width - tty_width($text);
+        my $total_spaces = $width - tty_length($text);
         my $left_spaces  = int($total_spaces / 2);
         my $right_spaces = $left_spaces;
         $right_spaces++ if $total_spaces % 2 == 1;
         return $pad.(' ' x $left_spaces).$text.(' ' x $right_spaces).$pad;
     }
     else {
-        return $pad.$text.' ' x ($width - tty_width($text)).$pad;
+        return $pad.$text.' ' x ($width - tty_length($text)).$pad;
     }
 }
 
@@ -188,11 +187,8 @@ sub _calculate_widths
         my @columns = @$row;
         for (my $i = 0; $i < @columns; $i++) {
             next unless defined($columns[$i]);
-
-            my $width = tty_width($columns[$i]);
-
-            $widths[$i] = $width if !defined($widths[$i])
-                                 || $width > $widths[$i];
+            $widths[$i] = tty_length($columns[$i]) if !defined($widths[$i])
+                                                   || tty_length($columns[$i]) > $widths[$i];
         }
     }
     return @widths;
